# coding: utf-8

"""
    OpenShift API (with Kubernetes)

    OpenShift provides builds, application lifecycle, image content management, and administrative policy on top of Kubernetes. The API allows consistent management of those objects.  All API operations are authenticated via an Authorization bearer token that is provided for service accounts as a generated secret (in JWT form) or via the native OAuth endpoint located at /oauth/authorize. Core infrastructure components may use client certificates that require no authentication.  All API operations return a 'resourceVersion' string that represents the version of the object in the underlying storage. The standard LIST operation performs a snapshot read of the underlying objects, returning a resourceVersion representing a consistent version of the listed objects. The WATCH operation allows all updates to a set of objects after the provided resourceVersion to be observed by a client. By listing and beginning a watch from the returned resourceVersion, clients may observe a consistent view of the state of one or more objects. Note that WATCH always returns the update after the provided resourceVersion. Watch may be extended a limited time in the past - using etcd 2 the watch window is 1000 events (which on a large cluster may only be a few tens of seconds) so clients must explicitly handle the \"watch to old error\" by re-listing.  Objects are divided into two rough categories - those that have a lifecycle and must reflect the state of the cluster, and those that have no state. Objects with lifecycle typically have three main sections:  * 'metadata' common to all objects * a 'spec' that represents the desired state * a 'status' that represents how much of the desired state is reflected on   the cluster at the current time  Objects that have no state have 'metadata' but may lack a 'spec' or 'status' section.  Objects are divided into those that are namespace scoped (only exist inside of a namespace) and those that are cluster scoped (exist outside of a namespace). A namespace scoped resource will be deleted when the namespace is deleted and cannot be created if the namespace has not yet been created or is in the process of deletion. Cluster scoped resources are typically only accessible to admins - resources like nodes, persistent volumes, and cluster policy.  All objects have a schema that is a combination of the 'kind' and 'apiVersion' fields. This schema is additive only for any given version - no backwards incompatible changes are allowed without incrementing the apiVersion. The server will return and accept a number of standard responses that share a common schema - for instance, the common error type is 'unversioned.Status' (described below) and will be returned on any error from the API server.  The API is available in multiple serialization formats - the default is JSON (Accept: application/json and Content-Type: application/json) but clients may also use YAML (application/yaml) or the native Protobuf schema (application/vnd.kubernetes.protobuf). Note that the format of the WATCH API call is slightly different - for JSON it returns newline delimited objects while for Protobuf it returns length-delimited frames (4 bytes in network-order) that contain a 'versioned.Watch' Protobuf object.  See the OpenShift documentation at https://docs.openshift.org for more information. 

    OpenAPI spec version: latest
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class V1ClairReportTag(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self, tag=None, creation_timestamp=None, latest_image=None, layer_count=None, vulnerabilities=None):
        """
        V1ClairReportTag - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'tag': 'str',
            'creation_timestamp': 'datetime',
            'latest_image': 'str',
            'layer_count': 'int',
            'vulnerabilities': 'list[V1ClairReportVulnerability]'
        }

        self.attribute_map = {
            'tag': 'tag',
            'creation_timestamp': 'creationTimestamp',
            'latest_image': 'latestImage',
            'layer_count': 'layerCount',
            'vulnerabilities': 'vulnerabilities'
        }

        self._tag = tag
        self._creation_timestamp = creation_timestamp
        self._latest_image = latest_image
        self._layer_count = layer_count
        self._vulnerabilities = vulnerabilities

    @property
    def tag(self):
        """
        Gets the tag of this V1ClairReportTag.
        Tag name

        :return: The tag of this V1ClairReportTag.
        :rtype: str
        """
        return self._tag

    @tag.setter
    def tag(self, tag):
        """
        Sets the tag of this V1ClairReportTag.
        Tag name

        :param tag: The tag of this V1ClairReportTag.
        :type: str
        """

        self._tag = tag

    @property
    def creation_timestamp(self):
        """
        Gets the creation_timestamp of this V1ClairReportTag.
        CreationTimestamp is a timestamp representing the server time when this tag was created. It is not guaranteed to be set in happens-before order across separate operations. Clients may not set this value. It is represented in RFC3339 form and is in UTC.  Populated by the system. Read-only. Null for lists. More info: http://releases.k8s.io/HEAD/docs/devel/api-conventions.md#metadata

        :return: The creation_timestamp of this V1ClairReportTag.
        :rtype: datetime
        """
        return self._creation_timestamp

    @creation_timestamp.setter
    def creation_timestamp(self, creation_timestamp):
        """
        Sets the creation_timestamp of this V1ClairReportTag.
        CreationTimestamp is a timestamp representing the server time when this tag was created. It is not guaranteed to be set in happens-before order across separate operations. Clients may not set this value. It is represented in RFC3339 form and is in UTC.  Populated by the system. Read-only. Null for lists. More info: http://releases.k8s.io/HEAD/docs/devel/api-conventions.md#metadata

        :param creation_timestamp: The creation_timestamp of this V1ClairReportTag.
        :type: datetime
        """

        self._creation_timestamp = creation_timestamp

    @property
    def latest_image(self):
        """
        Gets the latest_image of this V1ClairReportTag.
        Hash for latest seen image

        :return: The latest_image of this V1ClairReportTag.
        :rtype: str
        """
        return self._latest_image

    @latest_image.setter
    def latest_image(self, latest_image):
        """
        Sets the latest_image of this V1ClairReportTag.
        Hash for latest seen image

        :param latest_image: The latest_image of this V1ClairReportTag.
        :type: str
        """

        self._latest_image = latest_image

    @property
    def layer_count(self):
        """
        Gets the layer_count of this V1ClairReportTag.
        Standard object's metadata. More info: http://releases.k8s.io/HEAD/docs/devel/api-conventions.md#metadata

        :return: The layer_count of this V1ClairReportTag.
        :rtype: int
        """
        return self._layer_count

    @layer_count.setter
    def layer_count(self, layer_count):
        """
        Sets the layer_count of this V1ClairReportTag.
        Standard object's metadata. More info: http://releases.k8s.io/HEAD/docs/devel/api-conventions.md#metadata

        :param layer_count: The layer_count of this V1ClairReportTag.
        :type: int
        """

        self._layer_count = layer_count

    @property
    def vulnerabilities(self):
        """
        Gets the vulnerabilities of this V1ClairReportTag.
        List of found vulnerabilities

        :return: The vulnerabilities of this V1ClairReportTag.
        :rtype: list[V1ClairReportVulnerability]
        """
        return self._vulnerabilities

    @vulnerabilities.setter
    def vulnerabilities(self, vulnerabilities):
        """
        Sets the vulnerabilities of this V1ClairReportTag.
        List of found vulnerabilities

        :param vulnerabilities: The vulnerabilities of this V1ClairReportTag.
        :type: list[V1ClairReportVulnerability]
        """

        self._vulnerabilities = vulnerabilities

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, V1ClairReportTag):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other
